//
//  GCSAppDelegate.m
//  GiantColorSwatch
//
//  Created by Peter Hosey on 2006-04-03.
//  Copyright 2006 Peter Hosey. All rights reserved.
//

#import "GCSAppDelegate.h"

#define SAVED_COLOR_KEY @"Last used color"

@implementation GCSAppDelegate

#pragma mark Actions

- (IBAction)updateColor:sender {
	[window setBackgroundColor:[sender color]];
	[[window contentView] setNeedsDisplay:YES];
}

#pragma mark Nib awaking

- (void)awakeFromNib {
	[window setOpaque:NO]; //Enables translucency.

	NSData *savedColorData = [[NSUserDefaults standardUserDefaults] objectForKey:SAVED_COLOR_KEY];
	NSColor *savedColor = savedColorData ? [NSKeyedUnarchiver unarchiveObjectWithData:savedColorData] : [NSColor whiteColor];
	[window setBackgroundColor:savedColor];
}

#pragma mark NSApplication delegate conformance

- (void)applicationDidFinishLaunching:(NSNotification *)notification {
	//Development versions had the close button disabled. I decided to add a Show Colors menu item instead for the release.
	NSColorPanel *colorPanel = [NSColorPanel sharedColorPanel];
//	[[colorPanel standardWindowButton:NSWindowCloseButton]       setEnabled:NO];
	[[colorPanel standardWindowButton:NSWindowMiniaturizeButton] setEnabled:YES];

	[colorPanel setShowsAlpha:YES];
	[colorPanel setColor:[window backgroundColor]];

	[colorPanel setContinuous:YES];
	[colorPanel setAction:@selector(updateColor:)];
	[colorPanel setTarget:self];

	if(![window setFrameUsingName:[window frameAutosaveName]])
		[window center];
	[window orderFront:nil];
	[colorPanel makeKeyAndOrderFront:nil];
}

- (BOOL)applicationShouldTerminateAfterLastWindowClosed:(NSApplication *)app {
	return YES;
}

- (void)applicationWillTerminate:(NSNotification *)notification {
	NSColor *color = [window backgroundColor];
	if(color)
		[[NSUserDefaults standardUserDefaults] setObject:[NSKeyedArchiver archivedDataWithRootObject:color] forKey:SAVED_COLOR_KEY];

	[window release];
}

@end
